# +-----------------------------------------------------------------------+
# | pLoader - a Perl photo uploader for Piwigo                            |
# +-----------------------------------------------------------------------+
# | Copyright(C) 2008      Piwigo Team                  http://piwigo.org |
# +-----------------------------------------------------------------------+
# | This program is free software; you can redistribute it and/or modify  |
# | it under the terms of the GNU General Public License as published by  |
# | the Free Software Foundation                                          |
# |                                                                       |
# | This program is distributed in the hope that it will be useful, but   |
# | WITHOUT ANY WARRANTY; without even the implied warranty of            |
# | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
# | General Public License for more details.                              |
# |                                                                       |
# | You should have received a copy of the GNU General Public License     |
# | along with this program; if not, write to the Free Software           |
# | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
# | USA.                                                                  |
# +-----------------------------------------------------------------------+
package Uploader::GUI::wxGlobalSettings;
use strict;
use Wx qw/
            wxDefaultSize
            wxDefaultPosition
            wxTAB_TRAVERSAL 
            wxID_CANCEL
            wxID_OK
            wxGREEN
            wxHORIZONTAL
            wxVERTICAL
            wxFULL_REPAINT_ON_RESIZE
        /;
use base qw/Wx::Panel Uploader::GUI::DlgCommon/;
use Wx::Event qw/
            EVT_CLOSE
        /;

use Carp;
use Data::Dumper;

sub new {
    my ($this, $params) = @_;

    my $class = ref($this) || $this;


    my $self = $class->SUPER::new( $params->{parentwnd}, -1, wxDefaultPosition, wxDefaultSize, wxFULL_REPAINT_ON_RESIZE );
    $self->{tags} = $params->{tags};
    $self->{orientation} = $params->{orientation}||wxVERTICAL;

    # load controls
    &main::GlobalSettings($self);

    $self->properties(
        $params->{properties}
    );

    $self->frame_callback(
        $params->{frame_callback}
    );

    $self->{cpane_resize} = $self->FindWindow($main::CPANE_RESIZE);
    $self->{cpane_resize_advanced} = $self->FindWindow($main::CPANE_RESIZE_ADVANCED);
    $self->{cpane_hd} = $self->FindWindow($main::CPANE_HD);
    $self->{cpane_hd_advanced} = $self->FindWindow($main::CPANE_HD_ADVANCED);
    $self->{cpane_watermark} = $self->FindWindow($main::CPANE_WATERMARK);
    $self->{cpane_transfert_advanced} = $self->FindWindow($main::CPANE_TRANSFERT_ADVANCED);

    $self->InitLabels();
    $self->InitChoices();
    $self->SetProperties();
    $self->InitHandler();
    $self->_initEventHandlers();

    $self->_DefautPhotoCaption(
        $main::GS_DEFAULT_PHOTO_CAPTION
    );

    if($@){
        Wx::LogMessage("Error during dialogbox initialization");
    }

    $self;    
}



sub _initEventHandlers {
    my ( $self ) = @_;
    
    EVT_CLOSE( $self, \&OnClose );
    Wx::Event::EVT_COLLAPSIBLEPANE_CHANGED( $self, $self->{cpane_resize}, \&OnPaneChanged );
    Wx::Event::EVT_COLLAPSIBLEPANE_CHANGED( $self, $self->{cpane_resize_advanced}, \&OnPaneChanged );
    Wx::Event::EVT_COLLAPSIBLEPANE_CHANGED( $self, $self->{cpane_hd}, \&OnPaneChanged );
    Wx::Event::EVT_COLLAPSIBLEPANE_CHANGED( $self, $self->{cpane_hd_advanced}, \&OnPaneChanged );
    Wx::Event::EVT_COLLAPSIBLEPANE_CHANGED( $self, $self->{cpane_watermark}, \&OnPaneChanged );
    Wx::Event::EVT_COLLAPSIBLEPANE_CHANGED( $self, $self->{cpane_transfert_advanced}, \&OnPaneChanged );

}


sub OnClose {
    my ( $self, $event ) = @_;
    
    $self->_close;
}

sub _close {
    my ( $self ) = @_;


    $self->Destroy;
}

sub OnPaneChanged {
    my( $self, $event ) = @_;

    $self->_layout;
    $event->Skip;
}

sub _layout {
    my( $self ) = @_;

    $self->Layout; 
    $self->GetSizer->Fit($self);
    my $size = $self->GetSize;
    $self->frame_callback->($size);

}


sub OnDefaultPhotoCaption {
    my ( $self, $event ) = @_;
    
    $self->_DefautPhotoCaption(
        $event->GetId
    );

    $event->Skip;
}


sub _DefautPhotoCaption {
    my ( $self, $id ) = @_;

    my $b=0;
    if('CODE' eq ref $self->properties->{$id}->{string_selection}){
        if ( $self->properties->{$id}
            ->{string_selection}->() =~ /refix/ ){
            $b=1;
        }
    }

    map {
        $self->FindWindow($_)->Show($b)
    }(
        $main::PHOTO_CAPTION_PREFIX,
        $main::GS_PHOTO_CAPTION_PREFIX
    );
}

sub OnCreateResized {
    my ( $self, $event ) = @_;
    
    my $id = $event->GetId;
    my $b = 1;
    if('CODE' eq ref $self->properties->{$id}->{selection}){
        $b = !$self->properties->{$id}->{selection}->()
    }

    $self->{cpane_resize}->Collapse($b);
    $self->_layout;
    $event->Skip;

}


sub OnHDUpload {
    my ( $self, $event ) = @_;
    

    my $id = $event->GetId;
    my $b = 1;
    if('CODE' eq ref $self->properties->{$id}->{string_selection}){
        if ( $self->properties->{$id}
            ->{string_selection}->() =~ /resized/){
            $b = 0;
        }
    }
    $self->{cpane_hd}->Collapse($b);
    $self->_layout;
    $event->Skip;
}

sub OnWatermark {
    my ( $self, $event ) = @_;
    
    my $id = $event->GetId;
    my $b = 1;
    if('CODE' eq ref $self->properties->{$id}->{value}){
        $b = !$self->properties->{$id}->{value}->()
    }

    $self->{cpane_watermark}->Collapse($b);
    $self->_layout;
    $event->Skip;
}


1;